pub fn exit_no_alloc()Expand description
Undo one enter_no_alloc.
Exists for tests and for the embedded single thread mode (15 section 7),
where the caller’s thread is temporarily the shard and then goes back to
being the caller’s thread.
pub fn exit_no_alloc()Undo one enter_no_alloc.
Exists for tests and for the embedded single thread mode (15 section 7),
where the caller’s thread is temporarily the shard and then goes back to
being the caller’s thread.